@@ -90,8 +90,7 @@ def model_to_dict(instance, **options):
 
             if isinstance(value, models.Model):
                 if len(_options['fields']) == 1 and _options['flat'] and not _options['merge']:
-                    value = get_field_value(value, _options['fields'][0],
-                        allow_missing=_options['allow_missing'])
+                    value = serialize(value, **_options).values()[0]
                 else:
                     # Recurse, get the dict representation
                     _attrs = serialize(value, **_options)
@@ -110,7 +109,7 @@ def model_to_dict(instance, **options):
 
     # Apply post-hook to serialized attributes
     if options['posthook']:
-        attrs = options['posthook'](attrs)
+        attrs = options['posthook'](instance, attrs)
 
     return attrs
 
@@ -171,3 +170,5 @@ def serialize(obj, fields=None, exclude=None, **options):
     # Handle other iterables
     if hasattr(obj, '__iter__'):
         return map(lambda x: serialize(x, fields, exclude, **options), obj)
+
+    return obj
